@@ -13,10 +13,11 @@ package HiPi::Interface;
 use strict;
 use warnings;
 use parent qw( HiPi::Class );
+use Time::HiRes qw( usleep );
 
 __PACKAGE__->create_accessors( qw( device ) );
 
-our $VERSION ='0.70';
+our $VERSION ='0.71';
 
 sub new {
     my ($class, %params) = @_;
@@ -24,6 +25,16 @@ sub new {
     return $self;
 }
 
+sub delay {
+    my($class, $millis) = @_;
+    usleep( int($millis * 1000) );
+}
+
+sub delayMicroseconds {
+    my($class, $micros) = @_;
+    usleep( int($micros) );
+}
+
 sub DESTROY { $_[0]->device( undef ); } 
 
 1;
